@@ -30,11 +30,10 @@
 #include <libxml/xmlreader.h>
 #include <geocode-glib/geocode-glib.h>
 
-#define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
 #include "gweather-location.h"
 #include "gweather-timezone.h"
-#include "parser.h"
-#include "weather-priv.h"
+#include "gweather-parser.h"
+#include "gweather-private.h"
 
 /* This is the precision of coordinates in the database */
 #define EPSILON 0.000001
