@@ -19,11 +19,10 @@
 #ifndef __WEATHER_H_
 #define __WEATHER_H_
 
-#ifndef GWEATHER_I_KNOW_THIS_IS_UNSTABLE
-#error "libgweather should only be used if you understand that it's subject to change, and is not supported as a fixed API/ABI or as part of the platform"
+#if !(defined(IN_GWEATHER_H) || defined(GWEATHER_COMPILATION))
+#error "gweather-weather.h must not be included individually, include gweather.h instead"
 #endif
 
-
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libgweather/gweather-enums.h>
 #include <libgweather/gweather-location.h>
